@@ -36,6 +36,7 @@ from collections import Counter
 from scipy.ndimage import zoom
 from scipy.spatial import KDTree
 from scipy.interpolate import interp1d
+from scipy.stats import median_abs_deviation
 from matplotlib.colors import LogNorm
 from photutils.detection import DAOStarFinder
 from photutils.aperture import CircularAperture
@@ -137,11 +138,26 @@ AstrometryNet_API_key = 'ujmrvwqqyelxmzcj'
 #######################################################################
 
 
-def weighted_centre(x_coords, y_coords, weights):
-    weighted_x = np.sum(np.array(x_coords) * np.array(weights)) / np.sum(weights)
-    weighted_y = np.sum(np.array(y_coords) * np.array(weights)) / np.sum(weights)
+def weighted_centre(x_coords = None, 
+                    y_coords = None, 
+                    weights = None, 
+                    bins = 600):
+    
+    x_array, x_bin_edges = np.histogram(x_coords, bins = bins, weights = weights)
+    y_array, y_bin_edges = np.histogram(y_coords, bins = bins, weights = weights)
+
+    x_array_mask = x_array > median_abs_deviation(x_array)
+    y_array_mask = y_array > median_abs_deviation(y_array)
+
+    x_bin_centres = (x_bin_edges[:-1] + x_bin_edges[1:]) / 2
+    y_bin_centres = (y_bin_edges[:-1] + y_bin_edges[1:]) / 2
+    
+    weighted_x = np.sum(x_bin_centres * x_array_mask) / np.sum(x_array_mask)
+    weighted_y = np.sum(y_bin_centres * y_array_mask) / np.sum(y_array_mask)
+    
     return (weighted_x, weighted_y)
 
+
 def read_columns(events_list):
     # Reading few columns.
     f = fits.open(events_list)
@@ -158,6 +174,7 @@ def read_columns(events_list):
     photons = photons[mask]
     return time, fx, fy, photons
 
+
 def tobe_or_notobe(time, bwidth, 
                    detection_method,
                    threshold,
@@ -208,6 +225,7 @@ def tobe_or_notobe(time, bwidth,
             sanity = 0 
     return int(sanity) 
 
+
 def modify_string(events_list):
     if events_list[-5:] == '.fits':
         events_list = events_list[:-5]
@@ -215,6 +233,7 @@ def modify_string(events_list):
         events_list = events_list[:-8]
     return events_list
 
+
 # To automatically choose background region.
 def auto_bg(fx, fy, time, photons, radius, framecount_per_sec, sky_radius): 
     weights = photons / framecount_per_sec    
@@ -255,6 +274,7 @@ def auto_bg(fx, fy, time, photons, radius, framecount_per_sec, sky_radius):
     bg_CPS_e = np.mean(bg_CPS_e_sample[bg_CPS_mask])
     return lowres_counts, bg_CPS, bg_CPS_e   
     
+    
 # To estimate background CPS.
 def bg_estimate(fx, fy, time, photons, framecount_per_sec, radius, x_bg, y_bg, sky_radius):
 
@@ -276,6 +296,7 @@ def bg_estimate(fx, fy, time, photons, framecount_per_sec, radius, x_bg, y_bg, s
     bg_CPS_e = (scaled_events_e * framecount_per_sec) / Number_of_frames
     return bg_CPS, bg_CPS_e
 
+
 # To create subset images. 
 def create_sub_image(pos_x, pos_y, 
                      sub_size, 
@@ -301,6 +322,7 @@ def create_sub_image(pos_x, pos_y,
     plt.clf()
     return source_png_name  
 
+
 # To find positions of interest (using daofind algorithm).
 def detect_sources_daofind(fx, fy, photons, threshold):
     weights = photons / framecount_per_sec
@@ -333,6 +355,7 @@ def detect_sources_daofind(fx, fy, photons, threshold):
     uA = np.round(uA, 2)
     return uA
 
+
 # To find positions of interest (positions with maximum events).
 def detect_sources_kdtree(fx, fy, how_many):
     fxi = [int(round(s)) for s in fx]
@@ -358,6 +381,7 @@ def detect_sources_kdtree(fx, fy, how_many):
         uA = uA[mask]
     return uA
 
+
 def get_counts(fx, fy, time, photons, framecount_per_sec, xp, yp, radius):
 
     weights = photons / framecount_per_sec    
@@ -373,12 +397,14 @@ def get_counts(fx, fy, time, photons, framecount_per_sec, xp, yp, radius):
     CPF_err = np.sqrt(len(T)) / Number_of_frames
     return CPF, CPF_err
 
+
 # To change mission elapsed time in seconds to modified julian date.
 def met_to_mjd(met):
     jan2010 = 55197.0  # 2010.0(UTC) expressed with MJD format and scale UTC.
     mjd = (met / 86400.0) + jan2010  # 1 julian day = 86400 seconds.
     return mjd
 
+
 def apply_aperture_correction(CPF, CPF_err, radius, aperture_correction): 
     if aperture_correction == 'fuv':
         CPF = CPF / fuv_ratio_function(radius)
@@ -388,27 +414,27 @@ def apply_aperture_correction(CPF, CPF_err, radius, aperture_correction):
         CPF_err = CPF_err / nuv_ratio_function(radius)
     return CPF, CPF_err
     
-def apply_saturation_correction(CPF5, CPF5_err, saturation_correction):
     
-    if saturation_correction == True:
-        
-        if np.sum(CPF5 >= 0.6) != 0:
-            print("\nCounts per frame exeeds 0.6; saturation correction cannot be applied")
-            return
-        
-        ICPF5 = -1 * np.log(1 - CPF5)
-        ICPF5_err = CPF5_err / CPF5
-        
-        ICORR = ICPF5 - CPF5
-        ICORR_err = np.sqrt((ICPF5_err ** 2) + (CPF5_err ** 2))
-        
-        RCORR = ICORR * (0.89 - (0.30 * (ICORR ** 2)))
-        RCORR_err = RCORR * np.sqrt((ICORR_err ** 2) + ((0.30 * 2 * ICORR * ICORR_err) ** 2))
-        
-        CPF5 = CPF5 + RCORR
-        CPF5_err = np.sqrt((CPF5_err ** 2) + (RCORR_err ** 2))       
+def apply_saturation_correction(CPF5, CPF5_err):
+            
+    if np.sum(CPF5 >= 0.6) != 0:
+        print("\nCounts per frame exeeds 0.6; saturation correction cannot be applied")
+        return
+
+    ICPF5 = -1 * np.log(1 - CPF5)
+    ICPF5_err = CPF5_err / CPF5
+
+    ICORR = ICPF5 - CPF5
+    ICORR_err = np.sqrt((ICPF5_err ** 2) + (CPF5_err ** 2))
+
+    RCORR = ICORR * (0.89 - (0.30 * (ICORR ** 2)))
+    RCORR_err = RCORR * np.sqrt((ICORR_err ** 2) + ((0.30 * 2 * ICORR * ICORR_err) ** 2))
+
+    CPF5 = CPF5 + RCORR
+    CPF5_err = np.sqrt((CPF5_err ** 2) + (RCORR_err ** 2))       
     return CPF5, CPF5_err  
     
+    
 def makecurves(events_list = events_list,
                radius = radius,
                detection_method = detection_method,
@@ -510,7 +536,8 @@ def makecurves(events_list = events_list,
     saturation_correction : bool, optional
         If `True`, saturation correction is applied. 
         The default value is `False`. 
-
+        Note that aperture correction should be applied if you apply
+        saturation correction.         
 
     Note
     ---- 
@@ -696,9 +723,18 @@ def makecurves(events_list = events_list,
         CPF = CPF - (bg_CPS / framecount_per_sec)
         CPF_err = np.sqrt(CPF_err ** 2 + (bg_CPS_e / framecount_per_sec) ** 2)   
 
-        CPF, CPF_err = apply_aperture_correction(CPF, CPF_err, radius, aperture_correction)
-        CPF, CPF_err = apply_saturation_correction(CPF, CPF_err, saturation_correction)
-
+        if saturation_correction == True:
+            CPF, CPF_err = apply_aperture_correction(mcounts / frames_in_bin, 
+                                                     CPF_err, 
+                                                     radius, 
+                                                     aperture_correction)
+            flat_field_array = weighted_mcounts / mcounts
+            CPF, CPF_err = apply_saturation_correction(CPF, CPF_err)
+            CPF = CPF * flat_field_array
+        else:
+            CPF, CPF_err = apply_aperture_correction(CPF, CPF_err, 
+                                                     radius, 
+                                                     aperture_correction)
         
         CPS = CPF * framecount_per_sec
         CPS_err = CPF_err * framecount_per_sec
@@ -725,6 +761,7 @@ def makecurves(events_list = events_list,
 
     print('\nDone!\n')
     plt.close('all')
+     
         
 def curve(events_list = events_list,
           xp = xp,
@@ -818,7 +855,8 @@ def curve(events_list = events_list,
     saturation_correction : bool, optional
         If `True`, saturation correction is applied. 
         The default value is `False`. 
-
+        Note that aperture correction should be applied if you apply
+        saturation correction. 
 
     Note
     ---- 
@@ -827,6 +865,7 @@ def curve(events_list = events_list,
         
     Example
     --------
+    >>> import curvit
     >>> curvit.curve(events_list = 'AS1G06_084T01_9000000710uvtFIIPC00F1_l2ce.fits.gz', 
     ...              xp = 2636.71, yp = 907.91,
     ...              radius = 15,
@@ -986,8 +1025,18 @@ def curve(events_list = events_list,
     CPF = CPF - (bg_CPS / framecount_per_sec)
     CPF_err = np.sqrt(CPF_err ** 2 + (bg_CPS_e / framecount_per_sec) ** 2)    
 
-    CPF, CPF_err = apply_aperture_correction(CPF, CPF_err, radius, aperture_correction)
-    CPF, CPF_err = apply_saturation_correction(CPF, CPF_err, saturation_correction)
+    if saturation_correction == True:
+        CPF, CPF_err = apply_aperture_correction(mcounts / frames_in_bin, 
+                                                 CPF_err, 
+                                                 radius, 
+                                                 aperture_correction)
+        flat_field_array = weighted_mcounts / mcounts
+        CPF, CPF_err = apply_saturation_correction(CPF, CPF_err)
+        CPF = CPF * flat_field_array
+    else:
+        CPF, CPF_err = apply_aperture_correction(CPF, CPF_err, 
+                                                 radius, 
+                                                 aperture_correction)
     
     CPS = CPF * framecount_per_sec
     CPS_err = CPF_err * framecount_per_sec
@@ -1017,12 +1066,329 @@ def curve(events_list = events_list,
 
     print("\nDone!\n")
     plt.close('all') 
+ 
+    
+def curve_orbitwise(events_list = events_list,
+                    xp = xp,
+                    yp = yp,
+                    radius = radius,
+                    framecount_per_sec = framecount_per_sec,
+                    background = background,
+                    sky_radius = sky_radius,
+                    x_bg = x_bg,
+                    y_bg = y_bg,
+                    aperture_correction = aperture_correction,
+                    saturation_correction = saturation_correction,
+                    whole_figure_resolution = whole_figure_resolution,
+                    sub_fig_size = sub_fig_size,
+                    fontsize = fontsize):
+                   
+    """
+    Create a light curve for a source, generating one data point per orbit. 
+    This function works best with the combined events list produced using 
+    :doc:`/api/combine_events_lists`.
+
+    Parameters
+    ----------
+    events_list : file path
+        The name of the events list FITS file.
+        
+    xp : float
+        The X-coordinate of the source.
+        
+    yp : float
+        The Y-coordinate of the source. 
+        
+    radius : float, optional
+        The source aperture radius in pixels. 
+        This parameter has a default value of 6.        
+        
+    framecount_per_sec : float, optional
+        The framerate of the observation, with a default value of 28.7185
+        frames per second for 512 x 512 window mode. 
+        The most accurate way to get the framerate would be to take the value 
+        of (``1 / INT_TIME``). 
+        ``INT_TIME`` value can be found from the corresponding image header. 
+        Approximate values of framerate for different window modes of UVIT 
+        are given in the table below.
+
+        +---------------+---------------------+
+        | window mode   | frames per second   |
+        +===============+=====================+
+        | 512 x 512     | 28.7                |
+        +---------------+---------------------+
+        | 350 x 350     | 61                  |
+        +---------------+---------------------+
+        | 300 x 300     | 82                  |
+        +---------------+---------------------+
+        | 250 x 250     | 115                 |
+        +---------------+---------------------+
+        | 200 x 200     | 180                 |
+        +---------------+---------------------+
+        | 150 x 150     | 300                 |
+        +---------------+---------------------+
+        | 100 x 100     | 640                 |
+        +---------------+---------------------+ 
+
+    background : {'auto', 'manual', None}, optional
+        The parameter affects how the background count-rate estimation is done. 
+        
+        * ``'auto'``: Automatic estimation of the background count-rate.
+        * ``'manual'``: To manually specify a background region using **x_bg** and **y_bg** parameters.
+        * ``None``: No background estimation is carried out. This is the default method.
+     
+    sky_radius: float, optional
+        The background aperture radius in pixels. 
+        The default value is 12.
+        
+    x_bg : float, optional
+        The X-coordinate of the background region. 
+        
+    y_bg : float, optional
+        The Y-coordinate of the background region. 
+        
+    aperture_correction : {'fuv', 'nuv', None}, optional
+        The parameter affects how the aperture correction is done. 
+        
+        * ``'fuv'``: Aperture correction for the FUV channel is applied. 
+        * ``'nuv'``: Aperture correction for the NUV channel is applied.
+        * ``None``: No aperture correction is applied. This is the default method.
+        
+    saturation_correction : bool, optional
+        If `True`, saturation correction is applied. 
+        The default value is `False`. 
+        Note that aperture correction should be applied if you apply
+        saturation correction. 
+
+    Note
+    ---- 
+    It is essential to set the correct value of the framerate. 
+    Most UVIT observations are carried out in 512 x 512 window mode.
+        
+    Example
+    --------   
+    >>> import curvit     
+    >>> curvit.curve_orbitwise('AS1G05_240T01_9000000674uvtFIIPC00F2_l2ce_all_orbits.fits', 
+    ...                         xp = 1425.26, yp = 1861.78, 
+    ...                         radius = 15,
+    ...                         background = 'auto')    
+    
+    ::
+    
+        The estimated background CPS = 0.01473 +/-0.00073
+
+        -------------------------- curve --------------------------
+        source: source_AS1G05_240T01_9000000674uvtFIIPC00F2_l2ce_all_orbits.png
+                source_zoomed_AS1G05_240T01_9000000674uvtFIIPC00F2_l2ce_all_orbits.png
+        data: curve_orbitwise_1425.26_1861.78_AS1G05_240T01_9000000674uvtFIIPC00F2_l2ce_all_orbits.dat
+        plot: curve_orbitwise_1425.26_1861.78_AS1G05_240T01_9000000674uvtFIIPC00F2_l2ce_all_orbits.png
+
+        Done!
+    """
+
+    time, fx, fy, photons = read_columns(events_list)
+    weights = photons / framecount_per_sec
+
+    if None in [xp, yp]:
+        print('\nPlease provide values for both "xp" and "yp".\n')
+        return 
+    
+    sanity = tobe_or_notobe(time, 1, 
+                            detection_method,
+                            1,
+                            how_many, 
+                            background, 
+                            x_bg, y_bg,
+                            aperture_correction, radius,
+                            saturation_correction)
+    if sanity < 1:
+        return
+
+    path_to_events_list, events_list = ntpath.split(events_list)
+    events_list = modify_string(events_list)
+
+    # To automatically choose background region.
+    plt.figure(figsize = (10.5, 10))
+    if background == 'auto':
+        lowres_counts, bg_CPS, bg_CPS_e = auto_bg(fx, fy, time, photons, radius,
+                                                  framecount_per_sec, sky_radius)
+        
+    # To create a quick look figure marking sources and background.
+    bins = np.arange(0, 4801, 4096 / whole_figure_resolution)    
+    plt.hist2d(fx, fy, 
+               bins = (bins, bins),
+               weights = weights,
+               norm = LogNorm())
+
+    plt.tick_params(axis = 'both', labelsize = fontsize)
+
+    plt.annotate("Source", (xp, yp), 
+                 size = 13, color = 'black', fontweight = 'bold')
+
+    obj_circle = plt.Circle((xp, yp), 100, color = 'k', fill = False)
+    plt.gcf().gca().add_artist(obj_circle)
+
+    if background == 'manual':
+        plt.annotate('Background', (x_bg, y_bg),
+                     size = 13, color = 'black', fontweight = 'bold')
+
+        bg_circle = plt.Circle((x_bg, y_bg), 100, color = 'k', fill = False)
+        plt.gcf().gca().add_artist(bg_circle)
+        
+    png_name = os.path.join(path_to_events_list, 'source_' + events_list + '.png')
+    plt.savefig(png_name, format = 'png', bbox_inches = 'tight')
+    plt.clf()     
+        
+    source_png = create_sub_image(xp, yp, 
+                                  sub_fig_size, 
+                                  radius, 
+                                  'source_zoomed_',
+                                  fx, fy,
+                                  path_to_events_list,
+                                  events_list)
+    
+    if background != None:
+        if background == 'auto':
+            print('\nThe estimated background CPS = {:.5f} +/-{:.5f}'.format(bg_CPS, bg_CPS_e))
+        if background == 'manual':
+            # To estimate Background CPS.
+            bg_CPS, bg_CPS_e = bg_estimate(fx, fy, time, photons, framecount_per_sec,
+                                           radius, x_bg, y_bg, sky_radius)
+            bg_png = create_sub_image(x_bg, y_bg, 
+                                      sub_fig_size, 
+                                      sky_radius, 
+                                      'background_',
+                                      fx, fy,
+                                      path_to_events_list,
+                                      events_list)
+            print('\nThe estimated background CPS = {:.5f} +/-{:.5f}'.format(bg_CPS, bg_CPS_e))
+            print('Region selected for background estimate:\n* {}'.format(bg_png))
+    else:
+        bg_CPS, bg_CPS_e = 0, 0 
+
+    unique_time = np.unique(time)
+    unique_time = np.sort(unique_time)
+
+    # Define threshold for time differences (in seconds)
+    orbit_time_difference = 30 * 60 
+
+    # Calculate differences between consecutive elements
+    diffs = np.diff(unique_time)
+
+    # Find indices where differences exceed threshold
+    boundaries = np.where(diffs > orbit_time_difference)[0] + 1
+    
+    starts = np.concatenate([[0], boundaries])
+    ends = np.concatenate([boundaries - 1, [len(unique_time) -1]])
+    
+    starts = unique_time[starts]
+    ends = unique_time[ends]
+    
+    # Ranges for numpy histogram. 
+    ranges = np.concatenate([[0], boundaries, [len(unique_time) -1]])
+    ranges = unique_time[ranges]
+    
+    # selecting events within a circular region.
+    mask = ((fx - xp) ** 2 + (fy - yp) ** 2) <= radius ** 2    
+    T = time[mask]
+    W = weights[mask]  
+
+    # Changing mission elapsed time in seconds to modified julian date.
+    T = met_to_mjd(T)
+    # till_here = met_to_mjd(till_here)
+    # time_start = met_to_mjd(time.min())
+    unique_time = met_to_mjd(unique_time)
+    ranges = met_to_mjd(ranges)
+    
+    starts = met_to_mjd(starts)
+    ends = met_to_mjd(ends)
+    
+    time_start = ranges[0]
+    till_here = ranges[-1]
+    
+    # Binning stuff, plotting stuff.
+    plt.figure(figsize = (8, 5))
+    plt.title('radius = %spx' %(radius), fontsize = fontsize)
+    plt.xlabel("Time (Julian Date)", fontsize = fontsize)
+    plt.ylabel("Counts per second", fontsize = fontsize)
+    plt.tick_params(axis = 'both', labelsize = fontsize)
+
+    u_counts, u_bin_edges = np.histogram(unique_time, bins = ranges,
+                                         )
+
+    weighted_counts, bin_edges = np.histogram(T, bins = ranges, 
+                                              weights = W)    
+
+    counts, _ = np.histogram(T, bins = ranges)
+
+    bin_centres = (starts + ends) / 2.
+
+    count_mask = counts != 0
+
+    if np.sum(count_mask) != 0:
+        mcentres =  bin_centres[count_mask]
+        weighted_mcounts = weighted_counts[count_mask]
+        mcounts = counts[count_mask]
+        frames_in_bin = u_counts[count_mask]
+    else:
+        print('No counts inside the aperture!')
+
+    CPF = weighted_mcounts / frames_in_bin
+    CPF_err = np.sqrt(mcounts) / frames_in_bin
+    
+    # Background subtraction.
+    CPF = CPF - (bg_CPS / framecount_per_sec)
+    CPF_err = np.sqrt(CPF_err ** 2 + (bg_CPS_e / framecount_per_sec) ** 2)    
+
+    if saturation_correction == True:
+        CPF, CPF_err = apply_aperture_correction(mcounts / frames_in_bin, 
+                                                 CPF_err, 
+                                                 radius, 
+                                                 aperture_correction)
+        flat_field_array = weighted_mcounts / mcounts
+        CPF, CPF_err = apply_saturation_correction(CPF, CPF_err)
+        CPF = CPF * flat_field_array
+    else:
+        CPF, CPF_err = apply_aperture_correction(CPF, CPF_err, 
+                                                 radius, 
+                                                 aperture_correction)
+    
+    CPS = CPF * framecount_per_sec
+    CPS_err = CPF_err * framecount_per_sec
+
+    # Let us get on with the plot. 
+    plt.scatter(mcentres, CPS)
+    plt.errorbar(mcentres, CPS, yerr = CPS_err, linestyle = "None")
+    # To make the plot look good.
+    empty_space = (till_here - time_start) / 25.0
+    plt.xlim(time_start - empty_space, till_here + empty_space)
+
+    #To write the array to output.
+    data_to_output = list(zip(mcentres, CPS, CPS_err))
+    output_prefix = 'curve_orbitwise_' + str(xp) + '_' + str(yp) + '_' + events_list
+    datname = os.path.join(path_to_events_list, output_prefix + '.dat')
+    np.savetxt(datname, data_to_output,
+               fmt = '%10.11f\t%.5e\t%.5e',
+               header = 'MJD\t\t\tCPS\tCPS_error')
+
+    figname = os.path.join(path_to_events_list, output_prefix + '.png')
+    plt.savefig(figname, format = 'png', bbox_inches = 'tight', dpi = 150)
+
+    print('\n-------------------------- curve --------------------------')
+    print('source: {}\n        {}'.format(png_name, source_png))
+    print('data: {}'.format(datname))
+    print('plot: {}'.format(figname))
+
+    print("\nDone!\n")
+    plt.close('all') 
+              
     
 # Function to convert CCDLAB XYFrac and XYInts to X, Y positions in 4k.
 def CCDLAB_to_4k(Int, Frac):
     coo_in_4k = ((Int + Frac) - 16) / 4.0
     return coo_in_4k
     
+    
 # Function to convert CCDLAB files to a compatible events list.     
 def process_ccdlab(output = None,
                    time_list = None, 
@@ -1120,6 +1486,7 @@ def process_ccdlab(output = None,
     tbhdu.writeto(output, overwrite = True) 
     print('The events list: {}'.format(output))  
 
+
 def make_image(events_list = events_list, 
                framecount_per_sec = framecount_per_sec):
 
@@ -1197,12 +1564,14 @@ def make_image(events_list = events_list,
     hdu.writeto(fits_name, overwrite = True)      
     print('The image: {}'.format(fits_name))    
     
+    
 # Remove soon.    
 def makefits(events_list = events_list, 
              ramecount_per_sec = framecount_per_sec):
     print('Deprecated function. Please use make_image instead.')
     return make_image(events_list = events_list, 
                       framecount_per_sec = framecount_per_sec)    
+   
     
 def rebin(arr, bin_factor):
     shape = (int(arr.shape[0] / bin_factor), bin_factor,
@@ -1210,12 +1579,14 @@ def rebin(arr, bin_factor):
     binned_arr = arr.reshape(shape).mean(-1).mean(1)
     return binned_arr
 
+
 def get_image_data(fx, fy, photons, framecount_per_sec):
     weights = photons / framecount_per_sec
     bins = np.arange(0, 4801)
     data, _, _ = np.histogram2d(fy, fx, bins = (bins, bins), weights = weights)
     return data
 
+
 def daofind_on_image_data(data, threshold):
     kernel = Gaussian2DKernel(x_stddev=1.5)
     binned_data = rebin(data, 2)
@@ -1237,11 +1608,13 @@ def daofind_on_image_data(data, threshold):
     uA = np.array([sources['xcentroid'].data, sources['ycentroid'].data]).T
     return uA 
 
+
 def new_detect_sources_daofind(fx, fy, photons, threshold, framecount_per_sec):
     data = get_image_data(fx, fy, photons, framecount_per_sec)
     uA = daofind_on_image_data(data, threshold)
     return uA
 
+
 def combine_events_lists(events_lists_paths = None, 
                          threshold = 8,
                          NUM_NEAREST_NEIGHBORS = NUM_NEAREST_NEIGHBORS,
@@ -1552,6 +1925,7 @@ def combine_events_lists(events_lists_paths = None,
     hdu_base.close()
     print('The combined events list: {}'.format(combined_eventslist_name))    
     print("\nDone!\n")
+   
     
 def image_astrometry(UV_image = None, threshold = 3, API_key = AstrometryNet_API_key):
 
